@@ -41,7 +41,7 @@ static R_INLINE SEXP eval_call (SEXP fn, SEXP args, double *p, int n)
     *(REAL(CAR(var))) = *p;
 
   PROTECT(ob = LCONS(fn,args));
-  PROTECT(ans = eval(ob,CLOENV(fn)));
+  PROTECT(ans = eval(ob,R_ClosureEnv(fn)));
 
   UNPROTECT(2);
   return ans;
